import React from 'react';
import styled from 'styled-components';
import defaultTheme from '../../theme';
import { Box } from '../../elements';
const StyledInput = styled.input({
    margin: 0,
    outline: 0,
    textAlign: 'left',
    lineHeight: '1.5em',
    padding: '.5em 1em',
}, ({ theme }) => {
    return {
        borderRadius: theme.sizes.borderRadius,
        border: `1px solid ${theme.greyscale.medium}`,
        '&:focus, &:focus:hover, &:hover': {
            borderColor: theme.colors.primary.default,
        },
        '&:hover': {
            boxShadow: `1px 1px 12px 0 ${theme.greyscale.dark}`,
        },
    };
});
StyledInput.defaultProps = {
    theme: defaultTheme,
};
export const Input = ({ ref, ...props }) => {
    const safeRef = typeof ref !== 'string' ? ref : undefined;
    if (!props.label) {
        return React.createElement(StyledInput, Object.assign({}, props, { ref: safeRef }));
    }
    return (React.createElement(Box, { type: "row", verticalAlign: "center" },
        React.createElement(Box, { size: [1, 0.25] },
            React.createElement("label", null, props.label)),
        React.createElement(Box, { size: [1, 0.75] },
            React.createElement(StyledInput, Object.assign({}, props, { ref: safeRef })))));
};
