import { CSSObject, DefaultTheme } from 'styled-components';

import { HiroColors } from '../types';

export const clickable = <
  T extends {
    color?: HiroColors;
    disabled?: boolean;
    secondary?: boolean;
    theme: DefaultTheme;
  }
>({
  color,
  disabled,
  theme,
  secondary,
}: T): CSSObject => {
  const colorValue = theme.colors[color || 'primary'];

  return {
    cursor: 'pointer',

    // Disabled
    ...(disabled
      ? {
          pointerEvents: 'none' as const,
          opacity: 0.45,
        }
      : {}),

    // OnClick
    '&:active:hover': secondary
      ? {
          borderColor: colorValue.active,
          backgroundColor: colorValue.verylight,
        }
      : {
          backgroundColor: colorValue.active,
        },
    // Hover or focus
    '&:hover, &:focus': secondary
      ? {
          borderColor: colorValue.hover,
        }
      : {
          backgroundColor: colorValue.hover,
        },
  };
};
